summaryrefslogtreecommitdiffstats
path: root/bootstrap.sh
diff options
context:
space:
mode:
authorEvan Martin <martine@danga.com>2011-05-09 04:53:34 (GMT)
committerEvan Martin <martine@danga.com>2011-05-09 04:53:52 (GMT)
commit3a48d1027e594e39ee5dc526e9254387715a945e (patch)
tree1a35c1376fb514ede73940dd18bce5a3593c20e6 /bootstrap.sh
parent5d065405e6baf8aa57b2ef2a27d6eb0f36cff504 (diff)
downloadNinja-3a48d1027e594e39ee5dc526e9254387715a945e.zip
Ninja-3a48d1027e594e39ee5dc526e9254387715a945e.tar.gz
Ninja-3a48d1027e594e39ee5dc526e9254387715a945e.tar.bz2
rename gen-build-file to configure
Change it so it always writes build.ninja; easier to run directly.
Diffstat (limited to 'bootstrap.sh')
-rwxr-xr-xbootstrap.sh4
1 files changed, 2 insertions, 2 deletions
diff --git a/bootstrap.sh b/bootstrap.sh
index ee3e703..2566991 100755
--- a/bootstrap.sh
+++ b/bootstrap.sh
@@ -19,7 +19,7 @@ set -e
SYSTEMNAME=`uname -s`
# Compute system-specific CFLAGS/LDFLAGS as used in both in the below
# g++ call as well as in the later gen-build-file.py.
if [ "${SYSTEMNAME}" = "Linux" ]; then
export CFLAGS=
export LDFLAGS=
@@ -41,7 +41,7 @@ fi
g++ -Wno-deprecated ${CFLAGS} ${LDFLAGS} -o ninja.bootstrap $srcs
echo "Building ninja using itself..."
-./gen-build-file.py > build.ninja
+./configure.py
./ninja.bootstrap ninja
rm ninja.bootstrap
@@ -19,7 +19,7 @@ set -e
SYSTEMNAME=`uname -s`
# Compute system-specific CFLAGS/LDFLAGS as used in both in the below
-# g++ call as well as in the later gen-build-file.py.
+# g++ call as well as in the later configure.py.
if [ "${SYSTEMNAME}" = "Linux" ]; then
export CFLAGS=